@@ -1,6 +1,6 @@
 /*
     misc
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,98 +20,6 @@
 #include <gdk/gdkkeysyms.h>
 
 
-/******************************************************************************
-*                                                                             *
-* ja:メッセージボックス関数群                                                 *
-*                                                                             *
-******************************************************************************/
-/* ja:ボタンが押された */
-static void
-message_box_clicked (GtkWidget *widget,
-                     GtkWidget *dialog)
-{
-  *(gint *)g_object_get_data (G_OBJECT (dialog), "user_data")
-        = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "user_data"));
-  gtk_widget_destroy (dialog);
-}
-
-
-/* ja:ESCが押された */
-static gboolean
-message_box_dialog_key_press (GtkWidget   *widget,
-                              GdkEventKey *event,
-                              gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_widget_destroy (widget);
-  return FALSE;
-}
-
-
-/*  ja:メッセージボックスを表示する
-    title,タイトル
-     text,本文
-      def,デフォルトのボタン
-      ...,ボタンのラベル
-      RET,押されたボタン(-1:キャンセル)                                     */
-gint
-misc_message_box (const gchar *title,
-                  const gchar *text,
-                  const gint def, ...)
-{
-  va_list ap;
-  gchar *name;
-  gint i = 0, result = -1;
-  GtkWidget *dialog, *button, *label, *hbox0, *hbox1, *vbox, *focus = NULL;
-
-  va_start (ap, def);
-  /* ja:メインウインドウ */
-  dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_title (GTK_WINDOW (dialog), title);
-  g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
-                            G_CALLBACK (message_box_dialog_key_press), NULL);
-  g_signal_connect (G_OBJECT (dialog), "destroy", gtk_main_quit, NULL);
-  g_object_set_data (G_OBJECT (dialog), "user_data", &result);
-  /* ja:ラベル */
-  label = gtk_label_new(text);
-  /* ja:ボックス */
-  hbox0 = gtk_hbox_new (FALSE, SPACING);
-  /* ja:ボタン */
-  while ((name = va_arg (ap, gchar *)))
-    {
-      button = gtk_button_new_with_mnemonic (name);
-      g_signal_connect (G_OBJECT (button), "clicked",
-                                    G_CALLBACK (message_box_clicked), dialog);
-      g_object_set_data (G_OBJECT (button), "user_data", GINT_TO_POINTER (i));
-      GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-      if (i == def)
-        focus = button;
-      gtk_box_pack_start (GTK_BOX (hbox0), button, FALSE, FALSE, 0);
-      i++;
-    }
-  va_end (ap);
-
-  /* ja:ボックス */
-  vbox = gtk_vbox_new (FALSE, SPACING);
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
-  gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
-  hbox1 = gtk_hbox_new (FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (hbox1), hbox0, TRUE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (vbox), hbox1, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (dialog), vbox);
-
-  /* ja:表示 */
-  if (focus)
-    gtk_widget_grab_focus (focus);
-
-  gtk_grab_add (dialog);
-  gtk_widget_show_all (dialog);
-  gtk_main ();
-
-  return result;
-}
-
-
 /******************************************************************************
 *                                                                             *
 * ja:メニュー/ツールバー関数群                                                *
@@ -126,8 +34,9 @@ misc_create_menu (MiscCreateMenuEntry *entries,
 {
   gint i;
 
-  for (i = 0; entries[i].menu_type != MISC_CREATE_MENU_TERMINAL; i++)
-    switch (entries[i].menu_type)
+  for (i = 0; (entries[i].menu_type & MISC_CREATE_MENU_MASK)
+                                            != MISC_CREATE_MENU_TERMINAL; i++)
+    switch (entries[i].menu_type & MISC_CREATE_MENU_MASK)
       {
         case MISC_CREATE_MENU_BAR:
           entries[i].widget = gtk_menu_bar_new ();
@@ -151,15 +60,64 @@ misc_create_menu (MiscCreateMenuEntry *entries,
             g_free (path);
           }
           break;
-        case MISC_CREATE_MENU_ITEM:
-        case MISC_CREATE_MENU_SEPARATOR:
+        default:
           {
             gchar *path, *p;
             gint j;
 
-            entries[i].widget = entries[i].name
-                        ? gtk_menu_item_new_with_mnemonic (_(entries[i].name))
-                        : gtk_separator_menu_item_new ();
+            switch (entries[i].menu_type & MISC_CREATE_MENU_MASK)
+              {
+                case MISC_CREATE_MENU_STOCK:
+                  entries[i].widget = gtk_image_menu_item_new_from_stock
+                                        (entries[i].name,
+                                        entries[i].accel ? NULL : accel_group);
+                  break;
+                case MISC_CREATE_MENU_ITEM:
+                  if (entries[i].xpm)
+                    {
+                      GdkPixbuf *pixbuf;
+
+                      entries[i].widget = gtk_image_menu_item_new_with_mnemonic
+                                                        (_(entries[i].name));
+                      pixbuf = gdk_pixbuf_new_from_xpm_data (entries[i].xpm);
+                      gtk_image_menu_item_set_image
+                                    (GTK_IMAGE_MENU_ITEM (entries[i].widget),
+                                        gtk_image_new_from_pixbuf (pixbuf));
+                      g_object_unref (pixbuf);
+                    }
+                  else
+                    {
+                      entries[i].widget = gtk_menu_item_new_with_mnemonic
+                                                        (_(entries[i].name));
+                    }
+                  break;
+                case MISC_CREATE_MENU_CHECK:
+                  entries[i].widget = gtk_check_menu_item_new_with_mnemonic
+                                                        (_(entries[i].name));
+                  break;
+                case MISC_CREATE_MENU_RADIO:
+                  entries[i].widget = gtk_radio_menu_item_new_with_mnemonic
+                        (i > 0
+                        && (entries[i - 1].menu_type & MISC_CREATE_MENU_MASK)
+                                                     == MISC_CREATE_MENU_RADIO
+                            ? gtk_radio_menu_item_get_group
+                                (GTK_RADIO_MENU_ITEM (entries[i - 1].widget))
+                            : NULL, _(entries[i].name));
+                  break;
+                default:
+                  entries[i].widget = gtk_separator_menu_item_new ();
+              }
+            if (entries[i].menu_type & MISC_CREATE_MENU_ELLIPSIS)
+              {
+                gchar *mnemonic;
+                GtkWidget *label;
+
+                label = gtk_bin_get_child (GTK_BIN (entries[i].widget));
+                mnemonic = g_strconcat
+                        (gtk_label_get_label (GTK_LABEL (label)), "...", NULL);
+                gtk_label_set_text_with_mnemonic (GTK_LABEL (label), mnemonic);
+                g_free (mnemonic);
+              }
             path = g_strdup (entries[i].path);
             p = g_strrchr (path, '/') + 1 ;
             *p = '\0';
@@ -171,7 +129,7 @@ misc_create_menu (MiscCreateMenuEntry *entries,
                   break;
                 }
             g_free (path);
-            if (accel_group && entries[i].accel)
+            if (accel_group && entries[i].accel && entries[i].accel[0] != '\0')
               {
                 guint key;
                 GdkModifierType mods;
@@ -182,8 +140,15 @@ misc_create_menu (MiscCreateMenuEntry *entries,
                                         GTK_ACCEL_VISIBLE | GTK_ACCEL_LOCKED);
               }
             if (entries[i].func)
-              g_signal_connect (G_OBJECT (entries[i].widget), "activate",
+              g_signal_connect (G_OBJECT (entries[i].widget),
+                            (entries[i].menu_type & MISC_CREATE_MENU_MASK)
+                                                    == MISC_CREATE_MENU_CHECK
+                            || (entries[i].menu_type & MISC_CREATE_MENU_MASK)
+                                                    == MISC_CREATE_MENU_RADIO
+                                                    ? "toggled" : "activate",
                         G_CALLBACK (entries[i].func), entries[i].user_data);
+            if (entries[i].menu_type & MISC_CREATE_MENU_DISABLE)
+              gtk_widget_set_sensitive (entries[i].widget, FALSE);
           }
       }
 }
@@ -226,23 +191,69 @@ misc_create_toolbar (MiscCreateToolbarEntry *entries)
     {
       if (entries[i].name)
         {
-          GdkPixbuf *pixbuf;
+          if (entries[i].xpm)
+            {
+              GdkPixbuf *pixbuf;
 
-          pixbuf = gdk_pixbuf_new_from_xpm_data (entries[i].xpm);
-          entries[i].tool_item = gtk_tool_button_new
+              pixbuf = gdk_pixbuf_new_from_xpm_data (entries[i].xpm);
+#if GTK_CHECK_VERSION(2,4,0)
+              entries[i].tool_item = gtk_tool_button_new
                     (gtk_image_new_from_pixbuf (pixbuf), _(entries[i].name));
-          g_object_unref (pixbuf);
+              gtk_tool_item_set_tooltip (entries[i].tool_item, tooltips,
+                                    _(entries[i].name), _(entries[i].name));
+#else /* not GTK_CHECK_VERSION(2,4,0) */
+              entries[i].tool_item = gtk_toolbar_append_item
+                                            (GTK_TOOLBAR (toolbar),
+                                            _(entries[i].name),
+                                            _(entries[i].name),
+                                            _(entries[i].name),
+                                            gtk_image_new_from_pixbuf (pixbuf),
+                                            G_CALLBACK (entries[i].func),
+                                            NULL);
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
+              g_object_unref (pixbuf);
+            }
+          else
+            {
+              gchar *text;
+              GtkStockItem stock_item;
+
+              gtk_stock_lookup (entries[i].name, &stock_item);
+              text = misc_mnemonic_to_text (stock_item.label);
+#if GTK_CHECK_VERSION(2,4,0)
+              entries[i].tool_item = gtk_tool_button_new_from_stock
+                                                            (entries[i].name);
+              gtk_tool_item_set_tooltip (entries[i].tool_item, tooltips,
+                                                                text, text);
+#else /* not GTK_CHECK_VERSION(2,4,0) */
+              entries[i].tool_item = gtk_toolbar_insert_stock
+                                                (GTK_TOOLBAR (toolbar),
+                                                entries[i].name,
+                                                text,
+                                                text,
+                                                G_CALLBACK (entries[i].func),
+                                                NULL,
+                                                -1);
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
+              g_free (text);
+            }
+#if GTK_CHECK_VERSION(2,4,0)
           if (entries[i].func)
             g_signal_connect (G_OBJECT (entries[i].tool_item), "clicked",
                         G_CALLBACK (entries[i].func), entries[i].user_data);
-          gtk_tool_item_set_tooltip (entries[i].tool_item, tooltips,
-                                    _(entries[i].name), _(entries[i].name));
+#endif /* GTK_CHECK_VERSION(2,4,0) */
         }
       else
         {
+#if GTK_CHECK_VERSION(2,4,0)
           entries[i].tool_item = gtk_separator_tool_item_new ();
+#else /* not GTK_CHECK_VERSION(2,4,0) */
+          gtk_toolbar_append_space (GTK_TOOLBAR (toolbar));
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
         }
+#if GTK_CHECK_VERSION(2,4,0)
       gtk_toolbar_insert (GTK_TOOLBAR (toolbar), entries[i].tool_item, i);
+#endif /* GTK_CHECK_VERSION(2,4,0) */
     }
   return toolbar;
 }
@@ -270,6 +281,34 @@ misc_find_toolbar (MiscCreateToolbarEntry *entries,
 * ja:低レベル関数群                                                           *
 *                                                                             *
 ******************************************************************************/
+/*  ja:mnemonicをテキストに変換する
+    mnemonic,mnemonic
+         RET,テキスト                                                       */
+gchar *
+misc_mnemonic_to_text (const gchar *mnemonic)
+{
+  gchar *text;
+  gint i;
+
+  if (!mnemonic)
+    return NULL;
+  text = g_strdup (mnemonic);
+  for (i = 0; text[i] != '\0'; i++)
+    if (text[i] ==  '(' && text[i + 1] ==  '_'
+                    && g_ascii_isalpha (text[i + 2]) && text[i + 3] ==  ')')
+      {
+        g_memmove (text + i, text + i + 4, g_strlen (text + i) - 3);
+        break;
+      }
+    else if (text[i] == '_' && g_ascii_isalpha (text[i + 1]))
+      {
+        g_memmove (text + i, text + i + 2, g_strlen (text + i) - 1);
+        break;
+      }
+  return text;
+}
+
+
 /*  ja:スクロールバーを設定する
        scroll,スクロールウイジット
          func,シグナル関数
@@ -358,6 +397,18 @@ misc_scroll_window (GtkWidget  *widget,
 }
 
 
+/* ja:ESCが押されたとき */
+gboolean
+misc_dialog_key_press (GtkWidget   *widget,
+                       GdkEventKey *event,
+                       gpointer     user_data)
+{
+  if (event->keyval == GDK_Escape)
+    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
+  return FALSE;
+}
+
+
 /******************************************************************************
 *                                                                             *
 * ja:数値文字列関数群                                                         *
@@ -660,12 +711,12 @@ misc_str_to_float (gint        *value,
      flag,TRUE:符号あり,FALSE:符号なし
       RET,文字列                                                            */
 gchar *
-misc_str_from_array (gconstpointer  *array,
-                     const gsize     size,
-                     const gint      bits,
-                     const gint      radix,
-                     const gint      wide,
-                     const gboolean  flag)
+misc_str_from_array (gconstpointer  array,
+                     const gsize    size,
+                     const gint     bits,
+                     const gint     radix,
+                     const gint     wide,
+                     const gboolean flag)
 {
   gchar *p, *text = NULL;
   gint i, leng, length = 0;
@@ -775,149 +826,3 @@ misc_str_to_array (gsize          *size,
   g_free (p);
   return array;
 }
-
-
-/******************************************************************************
-*                                                                             *
-* ISO-10646                                                                   *
-*                                                                             *
-******************************************************************************/
-/*  ja:マルチバイト文字列→ワイド文字列
-       src,マルチバイト文字列
-    srclen,文字数(-1:NULL終了)
-       dst,ワイド文字列
-    dstlen,文字数
-       RET,文字数                                                           */
-gssize
-misc_multibyte_to_widechar (const gchar  *src,
-                            const gssize  srclen,
-                            guint16      *dst,
-                            const gssize  dstlen)
-{
-  gssize i, j, leng;
-
-  if (!src)
-    return 0;
-  leng = srclen < 0 ? g_strlen (src) + 1 : srclen;
-  i = j = 0;
-  if (!dst || dstlen <= 0)  /* ja:必要な文字数を数える */
-    while (i < leng)
-      {
-        if (i + 1 < leng && 0xc0 <= (guint8)src[i] && (guint8)src[i] <= 0xdf)
-          i += 2;
-        else if (i + 2 < leng && 0xe0 <= (guint8)src[i])
-          i += 3;
-        else
-          i++;
-        j++;
-      }
-  else                      /* ja:変換する */
-    while (i < leng && j < dstlen)
-      {
-        if (i + 1 < leng && 0xc0 <= (guint8)src[i] && (guint8)src[i] <= 0xdf)
-          {
-            dst[j] = (src[i] & 0x1f) << 6 | (src[i + 1] & 0x3f);
-            i += 2;
-          }
-        else if (i + 2 < leng && 0xe0 <= (guint8)src[i])
-          {
-            dst[j] = (src[i] & 0xf) << 12 | (src[i + 1] & 0x3f) << 6
-                                                        | (src[i + 2] & 0x3f);
-            i += 3;
-          }
-        else
-          {
-            dst[j] = src[i];
-            i++;
-          }
-        j++;
-      }
-  return j;
-}
-
-
-/*  ja:ワイド文字列→マルチバイト文字列
-       src,ワイド文字列
-    srclen,文字数(-1:NULL終了)
-       dst,マルチバイト文字列
-    dstlen,文字数
-       RET,文字数                                                           */
-gssize
-misc_widechar_to_multibyte (const guint16 *src,
-                            const gssize   srclen,
-                            gchar         *dst,
-                            const gssize   dstlen)
-{
-  gssize i, j, leng;
-
-  if (!src)
-    return 0;
-  if (srclen < 0)
-    {
-      for (leng = 0; src[leng] > 0; leng++);
-        leng++;
-    }
-  else
-    {
-      leng = srclen;
-    }
-  j = 0;
-  if (!dst || dstlen <= 0)  /* ja:必要な文字数を数える */
-    for (i = 0; i < leng; i++)
-      if (src[i] <= 0x007f)
-        j++;
-      else if (src[i] <= 0x07ff)
-        j += 2;
-      else
-        j += 3;
-  else                      /* ja:変換する */
-    for (i = 0; i < leng && j < dstlen; i++)
-      if (j + 1 == dstlen || src[i] <= 0x007f)
-        {
-          dst[j++] = src[i];
-        }
-      else if (j + 2 == dstlen || src[i] <= 0x07ff)
-        {
-          dst[j++] = 0xc0 | src[i] >> 6;
-          dst[j++] = 0x80 | (src[i] & 0x3f);
-        }
-      else
-        {
-          dst[j++] = 0xe0 | src[i] >> 12;
-          dst[j++] = 0x80 | (src[i] >> 6 & 0x3f);
-          dst[j++] = 0x80 | (src[i] & 0x3f);
-        }
-  return j;
-}
-
-
-/*  ja:マルチバイト文字列→ワイド文字列
-    src,マルチバイト文字列
-    RET,ワイド文字数,NULL:エラー                                            */
-guint16 *
-misc_multistring_to_widestring (const gchar *src)
-{
-  gssize leng;
-  guint16 *dst;
-
-  leng = misc_multibyte_to_widechar (src, -1, NULL, -1);
-  dst = g_malloc (leng * sizeof (guint16));
-  misc_multibyte_to_widechar (src, -1, dst, leng);
-  return dst;
-}
-
-
-/*  ja:ワイド文字列→マルチバイト文字列
-    src,ワイド文字列
-    RET,マルチバイト文字列,NULL:エラー                                      */
-gchar *
-misc_widestring_to_multistring (const guint16 *src)
-{
-  gssize leng;
-  gchar *dst;
-
-  leng = misc_widechar_to_multibyte (src, -1, NULL, -1);
-  dst = g_malloc (leng * sizeof (gchar));
-  misc_widechar_to_multibyte (src, -1, dst, leng);
-  return dst;
-}
