@@ -30,11 +30,14 @@ extern "C" {
 
 #define MISC_CREATE_MENU_BAR       1
 #define MISC_CREATE_MENU_SHELL     2
-#define MISC_CREATE_MENU_ITEM      3
-#define MISC_CREATE_MENU_SEPARATOR 4
-#define MISC_CREATE_MENU_STOCK     5
+#define MISC_CREATE_MENU_SEPARATOR 3
+#define MISC_CREATE_MENU_STOCK     4
+#define MISC_CREATE_MENU_ITEM      5
+#define MISC_CREATE_MENU_CHECK     6
+#define MISC_CREATE_MENU_RADIO     7
 #define MISC_CREATE_MENU_TERMINAL  0
 #define MISC_CREATE_MENU_ELLIPSIS  8
+#define MISC_CREATE_MENU_DISABLE   16
 #define MISC_CREATE_MENU_MASK      7
 
 typedef struct _MiscCreateMenuEntry
@@ -42,6 +45,7 @@ typedef struct _MiscCreateMenuEntry
   gchar *path;
   gchar *name;
   gchar *accel;
+  const gchar **xpm;
   guint menu_type;
   void (*func) (GtkWidget *widget, gpointer user_data);
   gpointer user_data;
