@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include <gdk/gdkkeysyms.h>
 #include "export.h"
 #include "general.h"
 #include "mm_list.h"
@@ -90,18 +89,6 @@ export_dialog_changed (GtkWidget    *widget,
 }
 
 
-/* ja:ESCが押された */
-static gboolean
-export_dialog_key_press (GtkWidget    *widget,
-                         GdkEventKey *event,
-                         gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-  return FALSE;
-}
-
-
 /*  ja:エクスポートダイアログ表示
     def_charset,デフォルトのキャラクターセット                              */
 ExportInfo *
@@ -117,11 +104,11 @@ export_dialog (const gchar *def_charset)
                             (_("Export"),
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             NULL);
-  g_signal_connect_after (G_OBJECT (expdlg.dialog), "key-press-event",
-                                G_CALLBACK (export_dialog_key_press), NULL);
+  g_signal_connect (G_OBJECT (expdlg.dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   /* ja:文字符号化方式 */
   expdlg.charset = orz_charset_new ();
   orz_charset_add_candidate (ORZ_CHARSET (expdlg.charset), charset_list);
