@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include <gdk/gdkkeysyms.h>
+#include "icons.h"
 #include "version.h"
 #include "misc/gnugpl.h"
 
@@ -26,18 +26,6 @@
 * ja:バージョン情報関数群                                                     *
 *                                                                             *
 ******************************************************************************/
-/* ja:ESCが押された */
-static gboolean
-version_dialog_key_press (GtkWidget   *widget,
-                          GdkEventKey *event,
-                          gpointer     user_data)
-{
-  if (event->keyval==GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-  return FALSE;
-}
-
-
 /*  ja:バージョン表示                                                       */
 void
 version_dialog (void)
@@ -59,50 +47,6 @@ const static gchar *authors =
 "Special Thanks :\n"
 "    kyun2\n"
 "    And all Melody maid users";
-const static gchar *mmaid_xpm[] = {
-"32 32 10 1",
-"   c None",
-".  c #000000",
-"=  c #C0C0C0",
-"-  c #FF0000",
-";  c #00FF00",
-">  c #FFFF00",
-",  c #0000FF",
-"'  c #FF00FF",
-")  c #00FFFF",
-"!  c #FFFFFF",
-"   =========================    ",
-"   =========================    ",
-"   .........................    ",
-"   .........................    ",
-"   ..)!)!)!)!)!)!)!)!)!)!)..    ",
-"   ..!)!)!)!)!)!)!)!)!)!)!..    ",
-"   ..)!)!)!)!)!)!)!)!)!)!)..    ",
-"   ..!)!)!)!)!)!)!)!)!)!)!..    ",
-"   ..)!)!)!)!)!)!)!)!)!)!)..    ",
-"   ..!)!)!)!)!)!)!)!)!)!)!..    ",
-"   ..)!)!)!)!)!)!)!)!)!)!)..    ",
-"   ..!)!)!)!)!)!)!)!)!)!)!..    ",
-"   ..)!)!)!)!)!)!)!)!)!)!)..    ",
-"   ............'............    ",
-"   ...........''............    ",
-"   ..........'''............    ",
-"   ..........'''............    ",
-"   ......-..'''',,,,,,......    ",
-"   ......---'''',,,,,.......    ",
-"   .......----'',,,)........    ",
-"   .......-----',)))........    ",
-"   ........--->;))))).......    ",
-"   ........->>>;;)))).......    ",
-"   .......>>>>>;;;;)))......    ",
-"   ......>>>>>>;;;;..)......    ",
-"   ............;;;..........    ",
-"   ............;;;..........    ",
-"   ............;;...........    ",
-"   ............;............    ",
-"   ..=====================..    ",
-"   =========================    ",
-"   =========================    "};
 
   /* ja:メインウインドウ */
   dialog = gtk_dialog_new_with_buttons
@@ -115,7 +59,7 @@ const static gchar *mmaid_xpm[] = {
   gtk_window_set_default_size (GTK_WINDOW (dialog),
                     gdk_screen_width () * 2 / 3, gdk_screen_height () * 2 / 3);
   g_signal_connect (G_OBJECT (dialog), "key-press-event",
-                                G_CALLBACK (version_dialog_key_press), NULL);
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   /* ja:ノートブック */
   notebook = gtk_notebook_new ();
   gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook), TRUE);
@@ -159,7 +103,7 @@ const static gchar *mmaid_xpm[] = {
   vbox = gtk_vbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
   hbox0 = gtk_hbox_new (FALSE, SPACING);
-  pixbuf = gdk_pixbuf_new_from_xpm_data (mmaid_xpm);
+  pixbuf = gdk_pixbuf_new_from_xpm_data (mmaid32_xpm);
   gtk_box_pack_start (GTK_BOX (hbox0),
                         gtk_image_new_from_pixbuf (pixbuf), FALSE, FALSE, 0);
   g_object_unref (pixbuf);
